@@ -22,6 +22,7 @@ from PySide6.QtWidgets import (QPushButton, QApplication,
 
 import meshtastic
 import meshtastic.serial_interface
+import meshtastic.util
 
 from meshtastic_flasher.version import __version__
 from meshtastic_flasher.advanced_form import AdvancedForm
@@ -246,12 +247,7 @@ class Form(QDialog):
     # pylint: disable=unused-argument
     def run_settings(self, event):
         """Run the settings form"""
-        if self.select_port.currentText() == '':
-            print('We do not have a port.')
-            QMessageBox.information(self, "Info", "Need a port before running Settings. Click DETECT DEVICE.")
-        else:
-            self.port = self.select_port.currentText()
-            self.settings.run(port=self.port)
+        self.settings.run(port=self.select_port.currentText())
 
 
     def on_select_firmware_changed(self, value):
@@ -355,15 +351,22 @@ class Form(QDialog):
         print("tips")
         msg_box = QMessageBox()
         msg_box.setTextFormat(QtCore.Qt.RichText)  # this is what makes the links clickable
-        msg_box.setText("Tips:<br><br>"
-                        "If having issues flashing the device, be sure there is only one device connected "
+        msg_box.setText("<u>Tips:</u><br>"
+                        "If having issues flashing the device, be sure there is only one <a href='https://meshtastic.org/docs/hardware'>supported device</a> connected "
                         "and no other applications are using that communications port.<br><br>"
                         "If still having problems, unplug the device, then re-plugin the device.<br><br>"
-                        "If still having problems, may need to install driver. "
-                        "See <a href='https://meshtastic.org/docs/getting-started/flashing-esp32'>Flashing</a> for more info.<br><br>"
+                        "If still having problems, consider using a different usb port, perhaps an external usb hub or even a different computer and/or different operating system.<br><br>"
+                        "If still having problems, may need to install driver.<br>"
+                        "See <a href='https://meshtastic.org/docs/getting-started/flashing-esp32'>Flashing</a> for more info. "
+                        "Newer T-Lora and newer T-Beams tend to need the CH9102 driver, which is in the CH343SER.ZIP file. "
+                        "The RAK 11200 may need the CP210X driver.<br>"
+                        "<u>Windows</u>: Check by going into DeviceManager and looking for any 'yellow' warning indicators.<br>"
+                        "<u>Mac</u>: Check by clicking in top left corner, 'About This Mac', 'System Report', 'USB'. Depending on which device it may show a CP2102 USB to UART Bridge Controller.<br>"
+                        "<u>Linux</u>: Linux tends to not need drivers for Meshtastic devices. If you have a computer available for the initial flashing, consider using this OS.<br><br>"
                         "If still having problems, try rebooting the pc.<br><br>"
                         "If you get a 'Critical Fault #6' on a T-Beam, it probably means you need to use "
-                        "v1.1 or v2.1.1.6 firmware.")
+                        "v1.1 or v2.1.1.6 firmware.<br><br>"
+                        "Join the <a href='https://discord.com/invite/UQJ5QuM7vq'>Meshtastic Discord group</a> and post questions in #help channel.")
         msg_box.setStandardButtons(QMessageBox.Ok)
         msg_box.exec()
 
@@ -449,7 +452,7 @@ class Form(QDialog):
            on Windows 11 and later
         """
         is_admin = None
-        if meshtastic_flasher.util.is_windows11():
+        if meshtastic.util.is_windows11():
             is_admin = ctypes.windll.shell32.IsUserAnAdmin() != 0
             if not is_admin:
                 print("Warning: This process is not running as Administrator.")
@@ -493,30 +496,11 @@ class Form(QDialog):
                                         "  After running that command, log out and re-login for it to take effect.\n"))
 
 
-    def update_ports_for_weird_tlora(self):
-        """Deal with weird T-Lora device (single device connected, but shows up as 2 ports)"""
-        ports = []
-        # ports:['/dev/cu.usbmodem11301', '/dev/cu.wchusbserial11301']
-        tmp_ports = meshtastic_flasher.util.wrapped_findPorts()
-        if len(tmp_ports) == 2:
-            if 'wchusbserial' in tmp_ports[1]:
-                first = tmp_ports[0].replace("usbmodem", "")
-                second = tmp_ports[1].replace("wchusbserial", "")
-                print(f'first:{first} second:{second}')
-                if first == second:
-                    print('We are dealing with a weird TLora port situation.')
-                    self.select_port.clear()
-                    self.select_port.addItem(tmp_ports[1])
-                    self.select_port.addItem(tmp_ports[0]) # delete this one?
-                    ports = tmp_ports
-        return ports
-
-
     def detect_ports_using_find_ports(self, ports, supported_devices_detected):
         """Detect ports using the find ports method in Meshtastic python library"""
         ports = []
         if len(ports) == 0:
-            print("Warning: Could not find any ports using the Meshtstic python autodetection method.")
+            print("Warning: Could not find any ports using the Meshtastic python autodetection method.")
 
             ports = meshtastic_flasher.util.wrapped_findPorts()
             if len(ports) == 0:
@@ -535,13 +519,8 @@ class Form(QDialog):
         ports = meshtastic_flasher.util.wrapped_active_ports_on_supported_devices(supported_devices_detected)
         ports_sorted = list(ports)
         ports_sorted.sort()
-        possible_weird = False
         for port in ports_sorted:
-            if 'usbmodem' in port:
-                possible_weird = True
             self.select_port.addItem(port)
-        if possible_weird:
-            ports = self.update_ports_for_weird_tlora()
         return ports
 
 
